@@ -2,18 +2,23 @@
 #' @description
 #' Internal workhorse function to calculate stopping boundary for a given method for time-to-event data
 #'
-#' @param n Maximum sample size for safety monitoring
+#' @param n maximum sample size for safety monitoring
 #' @param tau Length of observation period
 #' @param p0 The probability of a toxicity occurring in \code{tau} units of time under the null hypothesis
 #' @param type The method used for constructing the stopping rule
 #' @param cval Critical value for the stopping rule. For Wang-Tsiatis tests, this is the Delta parameter. For the Bayesian Gamma-Poisson method, this is the threshold on the posterior probability. For the truncated SPRT, this is the threshold on the log likelihood ratio. For the MaxSPRT, this is the threshold on the log generalized likelihood ratio.
+#' @param maxInf Specification of the maximum information (maximum exposure time) used for designing the
+#' stopping rule. Options include the expected exposure time for n patients used H0 ("expected") and the
+#' maximum possible exposure time ("maximum"). Default is "expected" (expected exposure time in cohort).
 #' @param param A vector of the extra parameter(s) needed for certain stopping rule methods. For Wang-Tsiatis tests, this is the Delta parameter. For truncated SPRT, this is the targeted alternative toxicity probability p1. For Bayesian Gamma-Poisson model, this is the vector of hyperparameters (shape,rate) for the gamma prior on the toxicity event rate.
 #'
 #' @return A list of three items: tau, number of events that can trigger a stop, and the corresponding total follow up time.
 
-calc.bnd.surv <- function(n, p0, type,  tau, cval, param = NULL){
+calc.bnd.surv = function(n, p0, type,  tau, cval, maxInf="expected", param = NULL){
   lambda0 = -log(1 - p0)/tau
-  Umax = n*tau
+  Ubound = n*tau
+  if(maxInf=="maximum") {Umax = n*tau}
+  else if(maxInf=="expected") {Umax = n*p0/lambda0}
 
   if (type == "Pocock"){
     f <- function(U){
@@ -60,7 +65,7 @@ calc.bnd.surv <- function(n, p0, type,  tau, cval, param = NULL){
     }
   }
   if (type != "GP"){
-    S <- seq(from = max(ceiling(f(0)),1), to = ceiling(f(Umax)))
+    S <- seq(from = max(ceiling(f(0)),1), to = ceiling(f(Ubound)))
     # FirstPositive <- which(S > 0)[1]
     # S <- S[FirstPositive:length(S)]
     dmin <- S[1]
@@ -71,7 +76,7 @@ calc.bnd.surv <- function(n, p0, type,  tau, cval, param = NULL){
     for (i in 1:m){
       ud[i] <- f.inverse(S[i])
     }
-    ud[length(ud)] <- Umax
+    ud[length(ud)] <- Ubound
   }
   if (type == "GP"){
     # hyperparameters
@@ -92,7 +97,7 @@ calc.bnd.surv <- function(n, p0, type,  tau, cval, param = NULL){
 
     post1 <- NULL
     for (d in 1:n){
-      post1[d] <- 1 - pgamma(lambda0, shape = (k + d), rate = (l + Umax))
+      post1[d] <- 1 - pgamma(lambda0, shape = (k + d), rate = (l + Ubound))
     }
     dmax = min(which(post1 >= cval))
     S = seq(dmin, dmax)
@@ -102,14 +107,14 @@ calc.bnd.surv <- function(n, p0, type,  tau, cval, param = NULL){
         1 - pgamma(lambda0, shape = (k + S[j]), rate = (l + ud))
       }
       if( j == 1){
-        ud[j] <- uniroot(function(ud){inner(ud) - cval}, lower = 0, upper = Umax,
+        ud[j] <- uniroot(function(ud){inner(ud) - cval}, lower = 0, upper = Ubound,
                          extendInt = "no", trace = 2)$root
       } else {
-        ud[j] <- uniroot(function(ud){inner(ud) - cval}, lower = ud[j-1], upper = Umax,
+        ud[j] <- uniroot(function(ud){inner(ud) - cval}, lower = ud[j-1], upper = Ubound,
                          extendInt = "no", trace = 2)$root
       }
     }
-    ud[length(ud)] <- Umax
+    ud[length(ud)] <- Ubound
   }
 
   return(list(tau = tau, Rule = cbind(ud,S)))
